==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/DNSListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DNSListFluent<A extends DNSListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,DNS item);
  public A setToItems(Integer index,DNS item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.DNS... items);
  public A addAllToItems(Collection<DNS> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.DNS... items);
  public A removeAllFromItems(Collection<DNS> items);
  public A removeMatchingFromItems(Predicate<DNSBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DNS> getItems();
  public List<DNS> buildItems();
  public DNS buildItem(Integer index);
  public DNS buildFirstItem();
  public DNS buildLastItem();
  public DNS buildMatchingItem(Predicate<DNSBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DNSBuilder> predicate);
  public A withItems(List<DNS> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.DNS... items);
  public Boolean hasItems();
  public DNSListFluent.ItemsNested<A> addNewItem();
  public DNSListFluent.ItemsNested<A> addNewItemLike(DNS item);
  public DNSListFluent.ItemsNested<A> setNewItemLike(Integer index,DNS item);
  public DNSListFluent.ItemsNested<A> editItem(Integer index);
  public DNSListFluent.ItemsNested<A> editFirstItem();
  public DNSListFluent.ItemsNested<A> editLastItem();
  public DNSListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DNSFluent<DNSListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/DNSListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DNSListFluent<A extends DNSListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,DNS item);
  public A setToItems(int index,DNS item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.DNS... items);
  public A addAllToItems(Collection<DNS> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.DNS... items);
  public A removeAllFromItems(Collection<DNS> items);
  public A removeMatchingFromItems(Predicate<DNSBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DNS> getItems();
  public List<DNS> buildItems();
  public DNS buildItem(int index);
  public DNS buildFirstItem();
  public DNS buildLastItem();
  public DNS buildMatchingItem(Predicate<DNSBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DNSBuilder> predicate);
  public A withItems(List<DNS> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.DNS... items);
  public Boolean hasItems();
  public DNSListFluent.ItemsNested<A> addNewItem();
  public DNSListFluent.ItemsNested<A> addNewItemLike(DNS item);
  public DNSListFluent.ItemsNested<A> setNewItemLike(int index,DNS item);
  public DNSListFluent.ItemsNested<A> editItem(int index);
  public DNSListFluent.ItemsNested<A> editFirstItem();
  public DNSListFluent.ItemsNested<A> editLastItem();
  public DNSListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DNSFluent<DNSListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
